@@ -38,6 +38,14 @@ GoogleSettings::GoogleSettings(const KSharedConfigPtr &config, Options options)
 
 void GoogleSettings::init()
 {
+    if (account().isEmpty()) {
+        qCWarning(GOOGLE_LOG) << Q_FUNC_INFO << "No username set";
+        Q_EMIT accountReady(false);
+        return;
+    }
+
+    qCWarning(GOOGLE_LOG) << "Trying to read password for" << account();
+
     // First read from QtKeyChain
     auto job = new QKeychain::ReadPasswordJob(googleWalletFolder, this);
     job->setKey(account());
@@ -49,11 +57,9 @@ void GoogleSettings::init()
         }
 
         // Found something with QtKeyChain
-        if (!account().isEmpty()) {
-            m_account = fetchAccountFromKeychain(account(), job);
-            m_isReady = true;
-            Q_EMIT accountReady(true);
-        }
+        m_account = fetchAccountFromKeychain(account(), job);
+        m_isReady = true;
+        Q_EMIT accountReady(true);
     });
     job->start();
 }
@@ -110,7 +116,6 @@ WritePasswordJob *GoogleSettings::storeAccount(AccountPtr account)
     auto writeJob = new WritePasswordJob(googleWalletFolder, this);
     writeJob->setKey(m_account->accountName());
     writeJob->setBinaryData(mapData);
-    writeJob->start();
 
     connect(writeJob, &WritePasswordJob::finished, this, [this, writeJob]() {
         if (writeJob->error()) {
